@@ -1,5 +1,8 @@
+/*
+ *  AntMAN Package
+ *
+ */
 
-#include "GibbsResultRCpp.h"
 #include "Mixtures.h"
 #include "Priors.h"
 #include "utils.h"
@@ -37,11 +40,6 @@ Mixture* gen_mix (Rcpp::List mixture_parameters) {
 		return new MixtureUnivariateNormal (mixture_parameters["m0"], mixture_parameters["k0"], mixture_parameters["nu0"], mixture_parameters["sig02"]);
 	}
 
-	if (mixture_parameters.containsElementNamed("a0") and mixture_parameters.containsElementNamed("b0")
-			and mixture_parameters.containsElementNamed("mb")) {
-		return  new MixtureUnivariateBernoulli (mixture_parameters["a0"], mixture_parameters["b0"], mixture_parameters["mb"]) ;
-	}
-
 
 
 	if (mixture_parameters.containsElementNamed("mu0") and mixture_parameters.containsElementNamed("ka0")
@@ -356,6 +354,45 @@ Prior* gen_prior (Rcpp::List mix_components_prior, Rcpp::List  mix_weight_prior
 
 
 
+Rcpp::List getList (AntMANLogger& logger) {
+
+	VERBOSE_INFO("Run getList");
+
+	std::vector<std::string> names = logger.getNames();
+
+	Rcpp::List my_list(names.size());
+	my_list.attr("names") = names;
+
+	int cnt = 0;
+	for (auto name : names) {
+		if (logger.haslog(name)) {
+			switch (logger.getlogtype(name)) {
+			case AntMANType::AM_INT : my_list[cnt++] = logger.getlog<int>(name) ; break;
+			case AntMANType::AM_UINT : my_list[cnt++] = logger.getlog<unsigned int>(name) ; break;
+			case AntMANType::AM_DOUBLE : my_list[cnt++] = logger.getlog<double>(name) ; break;
+			case AntMANType::AM_ARMA_VEC : my_list[cnt++] = logger.getlog<arma::vec>(name) ; break;
+			case AntMANType::AM_ARMA_MAT : my_list[cnt++] = logger.getlog<arma::mat>(name) ; break;
+			case AntMANType::AM_ARMA_CUBE : my_list[cnt++] = logger.getlog<arma::cube>(name) ; break;
+			case AntMANType::AM_ARMA_IVEC : my_list[cnt++] = logger.getlog<arma::ivec>(name) ; break;
+			case AntMANType::AM_ARMA_IMAT : my_list[cnt++] = logger.getlog<arma::imat>(name) ; break;
+			case AntMANType::AM_ARMA_ICUBE : my_list[cnt++] = logger.getlog<arma::icube>(name) ; break;
+			case AntMANType::AM_VEC_DOUBLE : my_list[cnt++] = logger.getlog<std::vector<double>>(name) ; break;
+			default :
+				VERBOSE_ERROR("Unsupported type!");
+			}
+
+
+
+		}
+	}
+
+	VERBOSE_INFO("Finish getList");
+
+	return my_list;
+
+
+
+}
 
 
 // INTERNAL FUNCTION - No DOCUMENTATION, Please only use AM_ refixed function.
@@ -375,7 +412,7 @@ Rcpp::List IAM_mcmc_fit (
 		VERBOSE_ASSERT(mcmc_parameters.containsElementNamed(item.c_str()), "mcmc_parameters does not contains : " << item );
 	}
 
-	VERBOSE_LEVEL = mcmc_parameters["verbose"] ;
+	VERBOSE_LEVEL(mcmc_parameters["verbose"]) ;
 
 	VERBOSE_DEBUG ("Debug mode is on.");
 
@@ -418,9 +455,7 @@ Rcpp::List IAM_mcmc_fit (
 
 
 	std::vector<std::string> output_list = Rcpp::as<std::vector<std::string>>(mcmc_parameters["output"]);
-	int output_codes = AM_GENERATOR_OUTPUT_CODE(output_list);
-	VERBOSE_INFO ("- size(mcmc_parameters[output]) = " << output_list.size());
-	VERBOSE_INFO ("- output_codes = " << output_codes);
+
 
 	unsigned long niter  = mcmc_parameters["niter"];
 	unsigned long burnin = mcmc_parameters["burnin"];
@@ -430,30 +465,58 @@ Rcpp::List IAM_mcmc_fit (
 
 	VERBOSE_ASSERT(niter > burnin, "Please keep niter > burnin.");
 	VERBOSE_ASSERT(niter > thin, "Please keep niter > thin.");
+	VERBOSE_ASSERT(thin  > 0, "Please keep thin > 0.");
 
 	VERBOSE_INFO(" - Stored observations " << stored);
-	GibbsResultRCpp res (  (niter - burnin)  / thin ,output_codes);
+	//GibbsResultRCpp res (  (niter - burnin)  / thin ,output_codes);
 
-	if (Rcpp::is<Rcpp::NumericMatrix>(y) || Rcpp::is<Rcpp::IntegerMatrix>(y)) {
-		VERBOSE_ASSERT (is_multivariate(mix_kernel_hyperparams), "y argument is a Matrix while the technique is not MultiVariate.") ;
+	AntMANLogger res(output_list, (niter - burnin)  / thin);
+	if (Rcpp::is<Rcpp::NumericMatrix>(y)) {
+			VERBOSE_ASSERT (is_multivariate(mix_kernel_hyperparams), "y argument is a Matrix while the technique is not MultiVariate.") ;
 
-		VERBOSE_INFO ("-  Rcpp::as<arma::mat>(y).n_rows = " << Rcpp::as<arma::mat>(y).n_rows);
-		dynamic_cast<MultivariateMixture*>(mixture)->fit(Rcpp::as<arma::mat>(y) , initial_clustering, fixed_clustering,
-				prior ,
-				niter ,burnin ,thin , parallel, &res );
-		VERBOSE_INFO("End of Gibbs");
-		return res.getList();
+			VERBOSE_INFO ("-  Rcpp::as<arma::mat>(y).n_rows = " << Rcpp::as<arma::mat>(y).n_rows);
+			MultivariateMixture* identifiedMixture = dynamic_cast<MultivariateMixture*>(mixture);
+			VERBOSE_ASSERT (identifiedMixture, "The input data type does not match the selected mixture. Need MultivariateMixture.");
+			identifiedMixture->fit(Rcpp::as<arma::mat>(y) , initial_clustering, fixed_clustering,
+					prior ,
+					niter ,burnin ,thin , parallel, &res );
+			VERBOSE_INFO("End of Gibbs");
+			return getList(res);
 
-	}  else if(Rcpp::is<Rcpp::NumericVector>(y) || Rcpp::is<Rcpp::IntegerVector>(y)){
-		VERBOSE_INFO ("-  Rcpp::as<arma::vec>(y).n_rows = " << Rcpp::as<arma::vec>(y).n_rows);
-		VERBOSE_ASSERT (is_univariate(mix_kernel_hyperparams), "y argument is a Vector while the technique is not Univariate.") ;
-		dynamic_cast<UnivariateMixture*>(mixture)->fit(Rcpp::as<arma::vec>(y) , initial_clustering, fixed_clustering, prior ,
-				niter ,burnin ,thin, parallel, &res );
+		}  else if (Rcpp::is<Rcpp::IntegerMatrix>(y)) {
+			VERBOSE_ASSERT (is_multivariate(mix_kernel_hyperparams), "y argument is a Matrix while the technique is not MultiVariate.") ;
 
-		VERBOSE_INFO("End of Gibbs");
-		return res.getList();
-	} else {
-		VERBOSE_ERROR("The parameter y must be a Matrix or a Vector.");
+			VERBOSE_INFO ("-  Rcpp::as<arma::imat>(y).n_rows = " << Rcpp::as<arma::imat>(y).n_rows);
+			MultivariateIntegerMixture* identifiedMixture = dynamic_cast<MultivariateIntegerMixture*>(mixture);
+			VERBOSE_ASSERT (identifiedMixture, "The input data type does not match the selected mixture. Need MultivariateIntegerMixture.");
+			identifiedMixture->fit(Rcpp::as<arma::imat>(y) , initial_clustering, fixed_clustering,
+					prior ,
+					niter ,burnin ,thin , parallel, &res );
+			VERBOSE_INFO("End of Gibbs");
+			return getList(res);
+
+		}  else if(Rcpp::is<Rcpp::NumericVector>(y) ){
+			VERBOSE_INFO ("-  Rcpp::as<arma::vec>(y).n_rows = " << Rcpp::as<arma::vec>(y).n_rows);
+			VERBOSE_ASSERT (is_univariate(mix_kernel_hyperparams), "y argument is a Vector while the technique is not Univariate.") ;
+			UnivariateMixture* identifiedMixture = dynamic_cast<UnivariateMixture*>(mixture);
+			VERBOSE_ASSERT (identifiedMixture, "The input data type does not match the selected mixture. Need UnivariateMixture.");
+			identifiedMixture->fit(Rcpp::as<arma::vec>(y) , initial_clustering, fixed_clustering, prior ,
+					niter ,burnin ,thin,   parallel, &res );
+
+			VERBOSE_INFO("End of Gibbs");
+			return getList(res);
+		} else if(Rcpp::is<Rcpp::IntegerVector>(y)){
+			VERBOSE_INFO ("-  Rcpp::as<arma::ivec>(y).n_rows = " << Rcpp::as<arma::ivec>(y).n_rows);
+			VERBOSE_ASSERT (is_univariate(mix_kernel_hyperparams), "y argument is a Vector while the technique is not Univariate.") ;
+			UnivariateIntegerMixture* identifiedMixture = dynamic_cast<UnivariateIntegerMixture*>(mixture);
+			VERBOSE_ASSERT (identifiedMixture, "The input data type does not match the selected mixture. Need UnivariateIntegerMixture.");
+			identifiedMixture->fit(Rcpp::as<arma::ivec>(y) , initial_clustering, fixed_clustering, prior ,
+					niter ,burnin ,thin,   parallel, &res );
+
+			VERBOSE_INFO("End of Gibbs");
+			return getList(res);
+		} else {
+		VERBOSE_ERROR("The parameter y must be a Matrix or a Vector and appriopriately Integer or Numeric.");
 	}
 	return Rcpp::List::create(Rcpp::Named("Error") = "Unexpected error."  );
 
