@@ -1,15 +1,14 @@
 /*
- * Mixtures.hpp
+ *  AntMAN Package
  *
- *  Created on: 26 May 2019
  */
 
+
 #ifndef SRC_MIXTURES_HPP_
 #define SRC_MIXTURES_HPP_
 
 #include "MixtureMultivariateBinomial.h"
 #include "MixtureMultiVariateNormal.h"
-#include "MixtureUnivariateBernoulli.h"
 #include "MixtureUnivariateNormal.h"
 #include "MixtureUnivariatePoisson.h"
 
