@@ -1,7 +1,13 @@
+#######################################################################################
+###############
+############### AntMAN Package : Tests and Examples
+###############
+###############
+#######################################################################################
+
 ##############################################
 ### Load the AntMan package
 ##############################################
-
 library("AntMAN")
 
 
@@ -21,8 +27,8 @@ plot(1:length(y_uvp),y_uvp,col=ci_uvp+1)
 ##############################################################################
 ### [NEW INTERFACE] PREPARE THE GIBBS for Poisson mixture with poisson dirac priors
 ##############################################################################
-mcmc_params        = AM_mcmc_parameters(niter=2000, burnin=1000, thin=10, verbose=3)
-mixture_uvp_params = AM_unipois_mix_hyperparams (alpha0=2, beta0=0.2)
+mcmc_params        = AM_mcmc_parameters(niter=2000, burnin=1000, thin=10, verbose=0, output=c("ALL"))
+mixture_uvp_params = AM_mix_hyperparams_unipois (alpha0=2, beta0=0.2)
 components_prior   = AM_mix_components_prior_dirac (Mstar=5) 
 weights_prior      = AM_mix_weights_prior_gamma(init=2, a=1, b=1)
 init_ci_uvp <- 0:(length(y_uvp)-1);
@@ -36,4 +42,10 @@ fit_poisson_dirac <- AM_mcmc_fit(
 
 
 summary (fit_poisson_dirac)
-plot (fit_poisson_dirac)
\ No newline at end of file
+plot (fit_poisson_dirac)
+
+eam = AM_clustering(fit_poisson_dirac)
+cluster = AM_salso(eam, "binder")
+#cluster = AM_binder(fit_poisson_dirac)$cluster 
+
+
